# Teflo OpenstackClient Plugin

The Teflo OpenstackClient Plugin provides a provisioner that utilizes the openstackclient to provision resources 
for scenarios.

Read more at [Teflo OpenstackClient Plugin Documentation](https://redhatqe.github.io/teflo_openstack_client_plugin/index.html)

For more information on Teflo refer [here](https://teflo.readthedocs.io/en/latest/)
